/*
 * Tapioca library
 * Copyright (C) 2005 INdT 
 * @author Andre Moreira Magalhaes <andre.magalhaes@indt.org.br>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __TAPIOCA_ENUMS_H__
#define __TAPIOCA_ENUMS_H__

#include <glib.h>

G_BEGIN_DECLS

/* Connection states */
typedef enum {
    TAPIOCA_CONNECTION_STATE_DISCONNECTED = 0,
    TAPIOCA_CONNECTION_STATE_CONNECTING,
    TAPIOCA_CONNECTION_STATE_CONNECTED,
    TAPIOCA_CONNECTION_STATE_LAST = TAPIOCA_CONNECTION_STATE_CONNECTED
} TapiocaConnectionState;

/* Proxy types */
typedef enum {
    TAPIOCA_PROXY_TYPE_NONE = 0,
    TAPIOCA_PROXY_TYPE_HTTPS,
    TAPIOCA_PROXY_TYPE_SOCKS,
    TAPIOCA_PROXY_TYPE_LAST = TAPIOCA_PROXY_TYPE_SOCKS
} TapiocaProxyType;

/* Session states */
typedef enum {
    TAPIOCA_SESSION_STATE_CLOSED = 0,
    TAPIOCA_SESSION_STATE_INITIATING,
    TAPIOCA_SESSION_STATE_ESTABLISHED,
    TAPIOCA_SESSION_STATE_LAST = TAPIOCA_SESSION_STATE_ESTABLISHED
} TapiocaSessionState;

/* Presence status */
typedef enum {
    TAPIOCA_PRESENCE_STATUS_OFFLINE = 0,
    TAPIOCA_PRESENCE_STATUS_AVAILABLE,
    TAPIOCA_PRESENCE_STATUS_AWAY,
    TAPIOCA_PRESENCE_STATUS_XA,
    TAPIOCA_PRESENCE_STATUS_DND,
    TAPIOCA_PRESENCE_STATUS_LAST = TAPIOCA_PRESENCE_STATUS_DND
} TapiocaPresenceStatus;

/* Privacy rule types */
typedef enum {
    TAPIOCA_PRIVACY_RULE_ADDRESS = 0,
    TAPIOCA_PRIVACY_RULE_GROUP,
    TAPIOCA_PRIVACY_RULE_SUBSCRIPTION,
    TAPIOCA_PRIVACY_RULE_LAST = TAPIOCA_PRIVACY_RULE_SUBSCRIPTION
} TapiocaPrivacyRule;

/* Privacy rule actions */
typedef enum {
    TAPIOCA_PRIVACY_RULE_ACTION_ACCEPT = 0,
    TAPIOCA_PRIVACY_RULE_ACTION_BLOCK,
    TAPIOCA_PRIVACY_RULE_ACTION_LAST = TAPIOCA_PRIVACY_RULE_ACTION_BLOCK
} TapiocaPrivacyRuleAction;

/* Contact list subscription state */
typedef enum {
    TAPIOCA_CONTACT_LIST_SUBSCRIPTION_STATE_NONE = 0,
    TAPIOCA_CONTACT_LIST_SUBSCRIPTION_STATE_TO,
    TAPIOCA_CONTACT_LIST_SUBSCRIPTION_STATE_FROM,
    TAPIOCA_CONTACT_LIST_SUBSCRIPTION_STATE_BOTH,
    TAPIOCA_CONTACT_LIST_SUBSCRIPTION_STATE_LOCAL,
    TAPIOCA_CONTACT_LIST_SUBSCRIPTION_STATE_LAST = TAPIOCA_CONTACT_LIST_SUBSCRIPTION_STATE_LOCAL
} TapiocaContactListSubscriptionState;

/* Session types */
typedef enum {
    TAPIOCA_SESSION_TYPE_UNKNOWN = 0,
    TAPIOCA_SESSION_TYPE_AUDIO,
    TAPIOCA_SESSION_TYPE_VIDEO,
    TAPIOCA_SESSION_TYPE_TEXT,
    TAPIOCA_SESSION_TYPE_LAST = TAPIOCA_SESSION_TYPE_TEXT
} TapiocaSessionType;

/* Text session message types */
typedef enum {
    TAPIOCA_TEXT_SESSION_MESSAGE_TYPE_NONE = 0,
    TAPIOCA_TEXT_SESSION_MESSAGE_TYPE_PLAIN_TEXT = 1,
    TAPIOCA_TEXT_SESSION_MESSAGE_TYPE_LAST = TAPIOCA_TEXT_SESSION_MESSAGE_TYPE_PLAIN_TEXT
} TapiocaTextSessionMessageType;

typedef enum {
    TAPIOCA_TEXT_SESSION_NOTIFICATION_STATE_NONE = 0,
    TAPIOCA_TEXT_SESSION_NOTIFICATION_STATE_ACTIVE = 1,
    TAPIOCA_TEXT_SESSION_NOTIFICATION_STATE_COMPOSING = 2,
    TAPIOCA_TEXT_SESSION_NOTIFICATION_STATE_PAUSED = 3,
    TAPIOCA_TEXT_SESSION_NOTIFICATION_STATE_INACTIVE = 4,
    TAPIOCA_TEXT_SESSION_NOTIFICATION_STATE_GONE = 5,
    TAPIOCA_TEXT_SESSION_NOTIFICATION_STATE_LAST = TAPIOCA_TEXT_SESSION_NOTIFICATION_STATE_GONE
} TapiocaTextSessionNotificationState;

G_END_DECLS

#endif
