/*
 * Tapioca library
 * Copyright (C) 2005 INdT 
 * @author Luiz Augusto von Dentz <luiz.dentz@indt.org.br>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __TAPIOCA_PRIVACY_H__
#define __TAPIOCA_PRIVACY_H__

#include <glib-object.h>

G_BEGIN_DECLS

#define TAPIOCA_TYPE_PRIVACY              (tapioca_privacy_get_type ())
#define TAPIOCA_PRIVACY(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), TAPIOCA_TYPE_PRIVACY, TapiocaPrivacy))
#define TAPIOCA_PRIVACY_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), TAPIOCA_TYPE_PRIVACY, TapiocaPrivacyClass))
#define IS_TAPIOCA_PRIVACY(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), TAPIOCA_TYPE_PRIVACY))
#define IS_TAPIOCA_PRIVACY_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), TAPIOCA_TYPE_PRIVACY))
#define TAPIOCA_PRIVACY_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), TAPIOCA_TYPE_PRIVACY, TapiocaPrivacyClass))
#define TAPIOCA_PRIVACY_GET_PRIVATE(obj)  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), TAPIOCA_TYPE_PRIVACY, TapiocaPrivacyPrivate))

typedef struct _TapiocaPrivacy        TapiocaPrivacy;
typedef struct _TapiocaPrivacyClass   TapiocaPrivacyClass;
typedef struct _TapiocaPrivacyPrivate TapiocaPrivacyPrivate;

struct _TapiocaPrivacyClass
{
    GObjectClass parent;

    /* callbacks */
    void (* request_lists)      (TapiocaPrivacy *tp);
    void (* request_list_rules) (TapiocaPrivacy *tp,
                                 const gchar *name);
    void (* get_default_list)   (TapiocaPrivacy *tp,
                                 const gchar **name);
    void (* set_default_list)   (TapiocaPrivacy *tp,
                                 const gchar *name);
    void (* get_active_list)    (TapiocaPrivacy *tp,
                                 const gchar **name);
    void (* set_active_list)    (TapiocaPrivacy *tp,
                                 const gchar *name);
    void (* add_list_rule)      (TapiocaPrivacy *tp,
                                 const gchar *list_name,
                                 guint type,
                                 const gchar *value,
                                 guint action);
    void (* remove_list_rule)   (TapiocaPrivacy *tp,
                                 const gchar *list_name,
                                 guint type,
                                 const gchar *value,
                                 guint action);
};

struct _TapiocaPrivacy
{
    GObject parent;

    TapiocaPrivacyPrivate *priv;
};

GType    tapioca_privacy_get_type                         (void);

void     tapioca_privacy_signal_rule_retrieved            (TapiocaPrivacy *tp,
                                                           const gchar *list_name,
                                                           guint type,
                                                           const gchar *value,
                                                           guint action);

void     tapioca_privacy_signal_lists_retrieved           (TapiocaPrivacy *tp,
                                                           gchar **lists);

G_END_DECLS

#endif
